| standsdmu | R Documentation |
This function standardizes the data matrix so that each variable will have mean 0 and std 1
standsdmu(dat)
dat |
Data matrix with rows are samples, columns are variables. |
A data matrix with each variable having mean 0 and std 1.
library(TestPMD)
data("covid")
mtb <- covid$metabolite
standsdmu(mtb)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.